// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:async';

import 'package:wyatt_architecture/wyatt_architecture.dart';
import 'package:wyatt_authentication_bloc/src/core/constants/form_field.dart';
import 'package:wyatt_authentication_bloc/src/core/constants/form_name.dart';
import 'package:wyatt_authentication_bloc/src/domain/entities/account.dart';
import 'package:wyatt_authentication_bloc/src/domain/repositories/authentication_repository.dart';
import 'package:wyatt_authentication_bloc/src/features/sign_in/cubit/mixin/sign_in_anonymously.dart';
import 'package:wyatt_authentication_bloc/src/features/sign_in/cubit/mixin/sign_in_with_email_password.dart';
import 'package:wyatt_authentication_bloc/src/features/sign_in/cubit/mixin/sign_in_with_google.dart';
import 'package:wyatt_form_bloc/wyatt_form_bloc.dart';
import 'package:wyatt_type_utils/wyatt_type_utils.dart';

part 'base_sign_in_cubit.dart';
part 'sign_in_state.dart';

/// {@template sign_in_cubit}
/// Fully featured sign in cubit.
///
/// Sufficient in most cases. (Where fine granularity is not required.)
/// {@endtemplate}
class SignInCubit<Data> extends BaseSignInCubit<Data>
    with
        SignInAnonymously<Data>,
        SignInWithEmailPassword<Data>,
        SignInWithGoogle<Data> {
  /// {@macro sign_in_cubit}
  SignInCubit({required super.authenticationRepository});

  @override
  FutureOrResult<Data?> onSignInAnonymously(
    Result<Account, AppException> result,
    WyattForm form,
  ) =>
      const Ok(null);

  @override
  FutureOrResult<Data?> onSignInWithEmailAndPassword(
    Result<Account, AppException> result,
    WyattForm form,
  ) =>
      const Ok(null);

  @override
  FutureOrResult<Data?> onSignInWithGoogle(
    Result<Account, AppException> result,
    WyattForm form,
  ) =>
      const Ok(null);
}
