// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// super program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// super program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with super program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/wyatt_ui_kit.dart';

class NavigationItem extends StatelessWidget {
  const NavigationItem({
    required this.item,
    required this.selected,
    super.key,
  });
  final TextWrapper item;
  final bool selected;

  @override
  Widget build(BuildContext context) => Stack(
        alignment: Alignment.bottomCenter,
        children: [
          if (selected)
            Container(
              height: ThemeHelper.getElement<double, double>(
                [
                  context
                      .themeExtension<TopBarThemeExtension>()
                      ?.selectedIndicatorSize
                      ?.height,
                  TopBarThemeExtensionDefault.from(Theme.of(context))
                      .selectedIndicatorSize
                      ?.height,
                ],
              ),
              width: ThemeHelper.getElement<double, double>(
                [
                  context
                      .themeExtension<TopBarThemeExtension>()
                      ?.selectedIndicatorSize
                      ?.width,
                  TopBarThemeExtensionDefault.from(Theme.of(context))
                      .selectedIndicatorSize
                      ?.width,
                ],
              ),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(100),
                gradient: ThemeHelper.maybeGetElement<MultiColor, Gradient>(
                  [
                    context
                        .themeExtension<TopBarThemeExtension>()
                        ?.selectedIndicatorColors,
                    TopBarThemeExtensionDefault.from(Theme.of(context))
                        .selectedIndicatorColors
                  ],
                  valueValidator: (value) => value?.isGradient,
                  transform: (value) =>
                      GradientHelper.linearFromNullableColors(value?.colors),
                ),
                color: ThemeHelper.getElement<MultiColor, Color>(
                  [
                    context
                        .themeExtension<TopBarThemeExtension>()
                        ?.selectedIndicatorColors,
                    TopBarThemeExtensionDefault.from(Theme.of(context))
                        .selectedIndicatorColors
                  ],
                  valueValidator: (value) => value?.isColor,
                  transform: (value) => value?.color,
                ),
              ),
            ),
          ConstrainedBox(
            constraints: BoxConstraints(
              minWidth: ThemeHelper.getElement<double, double>(
                [
                  context
                      .themeExtension<TopBarThemeExtension>()
                      ?.selectedIndicatorSize
                      ?.width,
                  TopBarThemeExtensionDefault.from(Theme.of(context))
                      .selectedIndicatorSize
                      ?.width,
                ],
              ),
            ),
            child: SizedBox(
              height: 50,
              child: Center(
                child: Text(
                  item.data,
                  style: ThemeHelper.getElement<TextStyle, TextStyle>(
                    [
                      TopBarThemeExtensionDefault.from(Theme.of(context))
                          .subtitleStyle,
                      context
                          .themeExtension<TopBarThemeExtension>()
                          ?.subtitleStyle,
                      item.style,
                    ],
                    combine: (value, element) => value?.merge(element),
                  ),
                ),
              ),
            ),
          ),
        ],
      );
}
