// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:wyatt_component_copy_with_extension/wyatt_component_copy_with_extension.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/cards/widgets/card_text.dart';
import 'package:wyatt_ui_kit/src/components/cards/widgets/card_wrapper.dart';

part 'quote_card.g.dart';

@ComponentCopyWithExtension()
class QuoteCard extends QuoteCardComponent with $QuoteCardCWMixin {
  const QuoteCard({
    super.avatar,
    super.name,
    super.subtitle,
    super.quote,
    super.leftQuote,
    super.rightQuote,
    super.radius,
    super.padding,
    super.borderColors,
    super.backgroundColors,
    super.stroke,
    super.minSize,
    super.maxSize,
    super.shadow,
    super.titleStyle,
    super.subtitleStyle,
    super.bodyStyle,
    super.background,
    super.key,
  });

  @override
  Widget build(BuildContext context) {
    final themeTitleStyle = ThemeHelper.maybeGetElement<TextStyle, TextStyle>(
      [
        titleStyle,
        Theme.of(context).extension<CardThemeExtension>()?.titleStyle,
        CardThemeExtensionDefault.from(Theme.of(context)).titleStyle,
      ],
    );

    final themeSubtitleStyle =
        ThemeHelper.maybeGetElement<TextStyle, TextStyle>(
      [
        subtitleStyle,
        Theme.of(context).extension<CardThemeExtension>()?.subtitleStyle,
        CardThemeExtensionDefault.from(Theme.of(context)).subtitleStyle,
      ],
    );

    final themeBodyStyle = ThemeHelper.maybeGetElement<TextStyle, TextStyle>(
      [
        bodyStyle,
        Theme.of(context).extension<CardThemeExtension>()?.bodyStyle,
        CardThemeExtensionDefault.from(Theme.of(context)).bodyStyle,
      ],
    );

    return CardWrapper(
      background: background,
      padding: padding,
      radius: radius,
      backgroundColors: backgroundColors,
      borderColors: borderColors,
      shadow: shadow,
      stroke: stroke,
      maxSize: maxSize,
      minSize: minSize,
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          leftQuote ??
              const Align(
                alignment: Alignment.topLeft,
                child: Text(
                  '“',
                ),
              ),
          if (quote != null) ...[
            CardText.fromWrapper(
              quote!,
              style: themeBodyStyle,
            ),
          ],
          const Gap(15),
          rightQuote ??
              const Align(
                alignment: Alignment.bottomRight,
                child: Text(
                  '”',
                ),
              ),
          Row(
            children: [
              if (avatar != null) ...[
                avatar!,
                const Gap(25),
              ],
              Expanded(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    if (name != null) ...[
                      CardText.fromWrapper(
                        name!,
                        style: themeTitleStyle,
                        textType: TextType.title,
                      ),
                    ],
                    if (subtitle != null) ...[
                      CardText.fromWrapper(
                        subtitle!,
                        style: themeSubtitleStyle,
                        textType: TextType.subtitle,
                      ),
                    ],
                  ],
                ),
              )
            ],
          ),
        ],
      ),
    );
  }
}
