// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';

/// {@template text_input_theme_extension}
/// Text input theme extension that implements Wyatt Theme
/// {@endtemplate}
class TextInputThemeExtensionImpl extends TextInputThemeExtension {
  /// {@macro text_input_theme_extension}
  const TextInputThemeExtensionImpl({
    super.normalStyle,
    super.focusedStyle,
    super.disabledStyle,
    super.invalidStyle,
  });

  factory TextInputThemeExtensionImpl.light({ThemeData? theme}) {
    theme ??= ThemeData.light();
    return TextInputThemeExtensionImpl(
      normalStyle: TextInputStyle(
        radius: BorderRadius.circular(12),
        borderColors: const Color.fromRGBO(221, 224, 227, 1),
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: const Color.fromRGBO(55, 65, 81, 1),
        ),
        inputStyle: theme.textTheme.bodyMedium?.copyWith(
          color: const Color.fromRGBO(55, 65, 81, 1),
        ),
      ),
      focusedStyle: TextInputStyle(
        radius: BorderRadius.circular(12),
        borderColors: const Color.fromRGBO(60, 125, 251, 1),
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: const Color.fromRGBO(55, 65, 81, 1),
        ),
        inputStyle: theme.textTheme.bodyMedium?.copyWith(
          color: const Color.fromRGBO(55, 65, 81, 1),
        ),
      ),
      invalidStyle: TextInputStyle(
        radius: BorderRadius.circular(12),
        borderColors: const Color.fromRGBO(244, 68, 100, 1),
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: const Color.fromRGBO(244, 68, 100, 1),
        ),
        inputStyle: theme.textTheme.bodyMedium?.copyWith(
          color: const Color.fromRGBO(55, 65, 81, 1),
        ),
      ),
      disabledStyle: TextInputStyle(
        radius: BorderRadius.circular(12),
        borderColors: const Color.fromRGBO(229, 231, 235, 1),
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: const Color.fromRGBO(156, 163, 175, 1),
        ),
        inputStyle: theme.textTheme.bodyMedium?.copyWith(
          color: const Color.fromRGBO(156, 163, 175, 1),
        ),
      ),
    );
  }

  factory TextInputThemeExtensionImpl.dark({ThemeData? theme}) {
    theme ??= ThemeData.dark();
    return TextInputThemeExtensionImpl(
      normalStyle: TextInputStyle(
        radius: BorderRadius.circular(12),
        borderColors: const Color.fromRGBO(96, 101, 106, 1),
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: const Color.fromRGBO(204, 204, 204, 1),
        ),
        inputStyle: theme.textTheme.bodyMedium?.copyWith(
          color: const Color.fromRGBO(255, 255, 255, 1),
        ),
      ),
      focusedStyle: TextInputStyle(
        radius: BorderRadius.circular(12),
        borderColors: const Color.fromRGBO(60, 125, 251, 1),
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: const Color.fromRGBO(204, 204, 204, 1),
        ),
        inputStyle: theme.textTheme.bodyMedium?.copyWith(
          color: const Color.fromRGBO(255, 255, 255, 1),
        ),
      ),
      invalidStyle: TextInputStyle(
        radius: BorderRadius.circular(12),
        borderColors: const Color.fromRGBO(244, 68, 100, 1),
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: const Color.fromRGBO(244, 68, 100, 1),
        ),
        inputStyle: theme.textTheme.bodyMedium?.copyWith(
          color: const Color.fromRGBO(255, 255, 255, 1),
        ),
      ),
      disabledStyle: TextInputStyle(
        radius: BorderRadius.circular(12),
        borderColors: const Color.fromRGBO(96, 101, 106, 1),
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: const Color.fromRGBO(96, 101, 106, 1),
        ),
        inputStyle: theme.textTheme.bodyMedium?.copyWith(
          color: const Color.fromRGBO(255, 255, 255, 1),
        ),
      ),
    );
  }
}
